@@ -1,6 +1,6 @@
 /* -*- C++ -*-
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2024 Cppcheck team.
+ * Copyright (C) 2007-2025 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 class Settings;
 class ErrorLogger;
 class SuppressionList;
+struct Suppressions;
 
 /**
  * This class works as an example of how CppCheck can be used in external
@@ -69,27 +70,29 @@ private:
 
 protected:
 
-    static bool reportSuppressions(const Settings &settings, const SuppressionList& suppressions, bool unusedFunctionCheckEnabled, const std::list<FileWithDetails> &files, const std::list<FileSettings>& fileSettings, ErrorLogger& errorLogger);
+    static bool reportUnmatchedSuppressions(const Settings &settings, const SuppressionList& suppressions, const std::list<FileWithDetails> &files, const std::list<FileSettings>& fileSettings, ErrorLogger& errorLogger);
 
     /**
      * Wrapper around check_internal
      *   - installs optional platform dependent signal handling
      *
      * @param settings the settings
+     * @param supprs the suppressions
      **/
-    int check_wrapper(const Settings& settings);
+    int check_wrapper(const Settings& settings, Suppressions& supprs);
 
     /**
      * Starts the checking.
      *
      * @param settings the settings
+     * @param supprs the suppressions
      * @return EXIT_FAILURE if arguments are invalid or no input files
      *         were found.
      *         If errors are found and --error-exitcode is used,
      *         given value is returned instead of default 0.
      *         If no errors are found, 0 is returned.
      */
-    int check_internal(const Settings& settings) const;
+    int check_internal(const Settings& settings, Suppressions& supprs) const;
 
     /**
      * Filename associated with size of file
