@@ -341,12 +341,9 @@ static bool isOperatorFunction(const std::string & funcName)
     return std::find(additionalOperators.cbegin(), additionalOperators.cend(), funcName.substr(operatorPrefix.length())) != additionalOperators.cend();
 }
 
-static void staticFunctionError(ErrorLogger& errorLogger,
-                                const std::string &filename,
-                                nonneg int fileIndex,
-                                nonneg int lineNumber,
-                                nonneg int column,
-                                const std::string &funcname)
+void CheckUnusedFunctions::staticFunctionError(ErrorLogger& errorLogger,
+                                               const std::string &filename, nonneg int fileIndex, nonneg int lineNumber, nonneg int column,
+                                               const std::string &funcname)
 {
     std::list<ErrorMessage::FileLocation> locationList;
     if (!filename.empty()) {
@@ -536,9 +533,7 @@ void CheckUnusedFunctions::updateFunctionData(const CheckUnusedFunctions& check)
         usage.fileIndex = entry.second.fileIndex;
         if (usage.filename.empty())
             usage.filename = entry.second.filename;
-        // cppcheck-suppress bitwiseOnBoolean - TODO: FP
         usage.usedOtherFile |= entry.second.usedOtherFile;
-        // cppcheck-suppress bitwiseOnBoolean - TODO: FP
         usage.usedSameFile |= entry.second.usedSameFile;
     }
     mFunctionDecl.insert(mFunctionDecl.cend(), check.mFunctionDecl.cbegin(), check.mFunctionDecl.cend());
