@@ -157,6 +157,9 @@ public:
                          const std::string &templateLocation) const;
 
     std::string serialize() const;
+    /**
+     * @throws InternalError thrown if deserialization failed
+     */
     void deserialize(const std::string &data);
 
     std::list<FileLocation> callStack;
@@ -179,7 +182,7 @@ public:
     std::string guideline;
 
     /** Warning hash */
-    std::size_t hash;
+    std::size_t hash{};
 
     /** set short and verbose messages */
     void setmsg(const std::string &msg);
@@ -190,7 +193,6 @@ public:
     }
 
     /** Verbose message (may be the same as the short message) */
-    // cppcheck-suppress unusedFunction - used by GUI only
     const std::string &verboseMessage() const {
         return mVerboseMessage;
     }
@@ -288,10 +290,10 @@ private:
 std::string replaceStr(std::string s, const std::string &from, const std::string &to);
 
 /** replaces the static parts of the location template **/
-CPPCHECKLIB void substituteTemplateFormatStatic(std::string& templateFormat);
+CPPCHECKLIB void substituteTemplateFormatStatic(std::string& templateFormat, bool eraseColors = false);
 
 /** replaces the static parts of the location template **/
-CPPCHECKLIB void substituteTemplateLocationStatic(std::string& templateLocation);
+CPPCHECKLIB void substituteTemplateLocationStatic(std::string& templateLocation, bool eraseColors = false);
 
 /** Get a classification string from the given guideline and reporttype */
 CPPCHECKLIB std::string getClassification(const std::string &guideline, ReportType reportType);
