@@ -33,7 +33,6 @@
 #include <fstream>
 #include <iostream>
 #include <iterator>
-#include <sstream>
 #include <stack>
 #include <unordered_set>
 #include <utility>
@@ -79,7 +78,7 @@ void ImportProject::fsSetDefines(FileSettings& fs, std::string defs)
     while (!defs.empty() && defs[0] == ';')
         defs.erase(0, 1);
     while (!defs.empty() && endsWith(defs,';'))
-        defs.erase(defs.size() - 1U); // TODO: Use std::string::pop_back() as soon as travis supports it
+        defs.pop_back();
     bool eq = false;
     for (std::size_t pos = 0; pos < defs.size(); ++pos) {
         if (defs[pos] == '(' || defs[pos] == '=')
@@ -165,7 +164,7 @@ void ImportProject::fsSetIncludePaths(FileSettings& fs, const std::string &basep
     }
 }
 
-ImportProject::Type ImportProject::import(const std::string &filename, Settings *settings, Suppressions *supprs, bool premium)
+ImportProject::Type ImportProject::import(const std::string &filename, Settings *settings, Suppressions *supprs)
 {
     std::ifstream fin(filename);
     if (!fin.is_open())
@@ -201,7 +200,7 @@ ImportProject::Type ImportProject::import(const std::string &filename, Settings
             return ImportProject::Type::BORLAND;
         }
     } else if (settings && supprs && endsWith(filename, ".cppcheck")) {
-        if (importCppcheckGuiProject(fin, *settings, *supprs, premium)) {
+        if (importCppcheckGuiProject(fin, *settings, *supprs)) {
             setRelativePaths(filename);
             return ImportProject::Type::CPPCHECK_GUI;
         }
@@ -211,11 +210,10 @@ ImportProject::Type ImportProject::import(const std::string &filename, Settings
     return ImportProject::Type::FAILURE;
 }
 
-static std::string readUntil(const std::string &command, std::string::size_type *pos, const char until[])
+static std::string readUntil(const std::string &command, std::string::size_type *pos, const char until[], bool str = false)
 {
     std::string ret;
     bool escapedString = false;
-    bool str = false;
     bool escape = false;
     for (; *pos < command.size() && (str || !std::strchr(until, command[*pos])); (*pos)++) {
         if (escape)
@@ -256,7 +254,7 @@ static std::string unescape(const std::string &in)
     return out;
 }
 
-void ImportProject::fsParseCommand(FileSettings& fs, const std::string& command)
+void ImportProject::fsParseCommand(FileSettings& fs, const std::string& command, bool doUnescape)
 {
     std::string defs;
 
@@ -267,6 +265,13 @@ void ImportProject::fsParseCommand(FileSettings& fs, const std::string& command)
             pos++;
         if (pos >= command.size())
             break;
+        bool wholeArgQuoted = false;
+        if (command[pos] == '"') {
+            wholeArgQuoted = true;
+            pos++;
+            if (pos >= command.size())
+                break;
+        }
         if (command[pos] != '/' && command[pos] != '-')
             continue;
         pos++;
@@ -277,14 +282,18 @@ void ImportProject::fsParseCommand(FileSettings& fs, const std::string& command)
             while (pos < command.size() && command[pos] == ' ')
                 ++pos;
         }
-        std::string fval = readUntil(command, &pos, " =");
+        std::string fval = readUntil(command, &pos, " =", wholeArgQuoted);
+        if (wholeArgQuoted && fval.back() == '\"')
+            fval.resize(fval.size() - 1);
         if (F=='D') {
             std::string defval = readUntil(command, &pos, " ");
             defs += fval;
-            if (defval.size() >= 3 && startsWith(defval,"=\"") && defval.back()=='\"')
-                defval = "=" + unescape(defval.substr(2, defval.size() - 3));
-            else if (defval.size() >= 5 && startsWith(defval, "=\\\"") && endsWith(defval, "\\\""))
-                defval = "=\"" + unescape(defval.substr(3, defval.size() - 5)) + "\"";
+            if (doUnescape) {
+                if (defval.size() >= 3 && startsWith(defval,"=\"") && defval.back()=='\"')
+                    defval = "=" + unescape(defval.substr(2, defval.size() - 3));
+                else if (defval.size() >= 5 && startsWith(defval, "=\\\"") && endsWith(defval, "\\\""))
+                    defval = "=\"" + unescape(defval.substr(3, defval.size() - 5)) + "\"";
+            }
             if (!defval.empty())
                 defs += defval;
             defs += ';';
@@ -334,7 +343,7 @@ bool ImportProject::importCompileCommands(std::istream &istr)
     picojson::value compileCommands;
     istr >> compileCommands;
     if (!compileCommands.is<picojson::array>()) {
-        printError("compilation database is not a JSON array");
+        errors.emplace_back("compilation database is not a JSON array");
         return false;
     }
 
@@ -344,12 +353,12 @@ bool ImportProject::importCompileCommands(std::istream &istr)
         picojson::object obj = fileInfo.get<picojson::object>();
 
         if (obj.count("directory") == 0) {
-            printError("'directory' field in compilation database entry missing");
+            errors.emplace_back("'directory' field in compilation database entry missing");
             return false;
         }
 
         if (!obj["directory"].is<std::string>()) {
-            printError("'directory' field in compilation database entry is not a string");
+            errors.emplace_back("'directory' field in compilation database entry is not a string");
             return false;
         }
 
@@ -362,8 +371,10 @@ bool ImportProject::importCompileCommands(std::istream &istr)
 
         const std::string directory = std::move(dirpath);
 
+        bool doUnescape = false;
         std::string command;
         if (obj.count("arguments")) {
+            doUnescape = false;
             if (obj["arguments"].is<picojson::array>()) {
                 for (const picojson::value& arg : obj["arguments"].get<picojson::array>()) {
                     if (arg.is<std::string>()) {
@@ -374,23 +385,24 @@ bool ImportProject::importCompileCommands(std::istream &istr)
                     }
                 }
             } else {
-                printError("'arguments' field in compilation database entry is not a JSON array");
+                errors.emplace_back("'arguments' field in compilation database entry is not a JSON array");
                 return false;
             }
         } else if (obj.count("command")) {
+            doUnescape = true;
             if (obj["command"].is<std::string>()) {
                 command = obj["command"].get<std::string>();
             } else {
-                printError("'command' field in compilation database entry is not a string");
+                errors.emplace_back("'command' field in compilation database entry is not a string");
                 return false;
             }
         } else {
-            printError("no 'arguments' or 'command' field found in compilation database entry");
+            errors.emplace_back("no 'arguments' or 'command' field found in compilation database entry");
             return false;
         }
 
         if (!obj.count("file") || !obj["file"].is<std::string>()) {
-            printError("skip compilation database entry because it does not have a proper 'file' field");
+            errors.emplace_back("skip compilation database entry because it does not have a proper 'file' field");
             continue;
         }
 
@@ -413,7 +425,7 @@ bool ImportProject::importCompileCommands(std::istream &istr)
         else
             path = Path::simplifyPath(directory + file);
         FileSettings fs{path, Standards::Language::None, 0}; // file will be identified later on
-        fsParseCommand(fs, command); // read settings; -D, -I, -U, -std, -m*, -f*
+        fsParseCommand(fs, command, doUnescape); // read settings; -D, -I, -U, -std, -m*, -f*
         std::map<std::string, std::string, cppcheck::stricmp> variables;
         fsSetIncludePaths(fs, directory, fs.includePaths, variables);
         // Assign a unique index to each file path. If the file path already exists in the map,
@@ -430,14 +442,14 @@ bool ImportProject::importSln(std::istream &istr, const std::string &path, const
     std::string line;
 
     if (!std::getline(istr,line)) {
-        printError("Visual Studio solution file is empty");
+        errors.emplace_back("Visual Studio solution file is empty");
         return false;
     }
 
     if (!startsWith(line, "Microsoft Visual Studio Solution File")) {
         // Skip BOM
         if (!std::getline(istr, line) || !startsWith(line, "Microsoft Visual Studio Solution File")) {
-            printError("Visual Studio solution file header not found");
+            errors.emplace_back("Visual Studio solution file header not found");
             return false;
         }
     }
@@ -462,14 +474,14 @@ bool ImportProject::importSln(std::istream &istr, const std::string &path, const
             vcxproj = path + vcxproj;
         vcxproj = Path::fromNativeSeparators(std::move(vcxproj));
         if (!importVcxproj(vcxproj, variables, "", fileFilters, sharedItemsProjects)) {
-            printError("failed to load '" + vcxproj + "' from Visual Studio solution");
+            errors.emplace_back("failed to load '" + vcxproj + "' from Visual Studio solution");
             return false;
         }
         found = true;
     }
 
     if (!found) {
-        printError("no projects found in Visual Studio solution file");
+        errors.emplace_back("no projects found in Visual Studio solution file");
         return false;
     }
 
@@ -533,8 +545,7 @@ namespace {
             // TODO: improve evaluation
             const Settings s;
             TokenList tokenlist(s, Standards::Language::C);
-            std::istringstream istr(c);
-            tokenlist.createTokens(istr); // TODO: check result
+            tokenlist.createTokensFromBuffer(c.data(), c.size()); // TODO: check result
             // TODO: put in a helper
             // generate links
             {
@@ -727,7 +738,7 @@ bool ImportProject::importVcxproj(const std::string &filename,
     tinyxml2::XMLDocument doc;
     const tinyxml2::XMLError error = doc.LoadFile(filename.c_str());
     if (error != tinyxml2::XML_SUCCESS) {
-        printError(std::string("Visual Studio project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
+        errors.emplace_back(std::string("Visual Studio project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
         return false;
     }
     return importVcxproj(filename, doc, variables, additionalIncludeDirectories, fileFilters, cache);
@@ -746,7 +757,7 @@ bool ImportProject::importVcxproj(const std::string &filename, const tinyxml2::X
 
     const tinyxml2::XMLElement * const rootnode = doc.FirstChildElement();
     if (rootnode == nullptr) {
-        printError("Visual Studio project file has no XML root node");
+        errors.emplace_back("Visual Studio project file has no XML root node");
         return false;
     }
     for (const tinyxml2::XMLElement *node = rootnode->FirstChildElement(); node; node = node->NextSiblingElement()) {
@@ -807,13 +818,13 @@ bool ImportProject::importVcxproj(const std::string &filename, const tinyxml2::X
                                 pathToSharedItemsFile = variables["ProjectDir"] + projectAttribute;
                             }
                             if (!simplifyPathWithVariables(pathToSharedItemsFile, variables)) {
-                                printError("Could not simplify path to referenced shared items project");
+                                errors.emplace_back("Could not simplify path to referenced shared items project");
                                 return false;
                             }
 
                             SharedItemsProject toAdd = importVcxitems(pathToSharedItemsFile, fileFilters, cache);
                             if (!toAdd.successful) {
-                                printError("Could not load shared items project \"" + pathToSharedItemsFile + "\" from original path \"" + std::string(projectAttribute) + "\".");
+                                errors.emplace_back("Could not load shared items project \"" + pathToSharedItemsFile + "\" from original path \"" + std::string(projectAttribute) + "\".");
                                 return false;
                             }
                             sharedItemsProjects.emplace_back(toAdd);
@@ -925,12 +936,12 @@ ImportProject::SharedItemsProject ImportProject::importVcxitems(const std::strin
     tinyxml2::XMLDocument doc;
     const tinyxml2::XMLError error = doc.LoadFile(filename.c_str());
     if (error != tinyxml2::XML_SUCCESS) {
-        printError(std::string("Visual Studio project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
+        errors.emplace_back(std::string("Visual Studio project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
         return result;
     }
     const tinyxml2::XMLElement * const rootnode = doc.FirstChildElement();
     if (rootnode == nullptr) {
-        printError("Visual Studio project file has no XML root node");
+        errors.emplace_back("Visual Studio project file has no XML root node");
         return result;
     }
     for (const tinyxml2::XMLElement *node = rootnode->FirstChildElement(); node; node = node->NextSiblingElement()) {
@@ -948,7 +959,7 @@ ImportProject::SharedItemsProject ImportProject::importVcxitems(const std::strin
 
                         result.sourceFiles.emplace_back(file);
                     } else {
-                        printError("Could not find shared items source file");
+                        errors.emplace_back("Could not find shared items source file");
                         return result;
                     }
                 }
@@ -976,12 +987,12 @@ bool ImportProject::importBcb6Prj(const std::string &projectFilename)
     tinyxml2::XMLDocument doc;
     const tinyxml2::XMLError error = doc.LoadFile(projectFilename.c_str());
     if (error != tinyxml2::XML_SUCCESS) {
-        printError(std::string("Borland project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
+        errors.emplace_back(std::string("Borland project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
         return false;
     }
     const tinyxml2::XMLElement * const rootnode = doc.FirstChildElement();
     if (rootnode == nullptr) {
-        printError("Borland project file has no XML root node");
+        errors.emplace_back("Borland project file has no XML root node");
         return false;
     }
 
@@ -1287,18 +1298,18 @@ static std::string istream_to_string(std::istream &istr)
     return std::string(std::istreambuf_iterator<char>(istr), eos);
 }
 
-bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings &settings, Suppressions &supprs, bool premium)
+bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings &settings, Suppressions &supprs)
 {
     tinyxml2::XMLDocument doc;
     const std::string xmldata = istream_to_string(istr);
     const tinyxml2::XMLError error = doc.Parse(xmldata.data(), xmldata.size());
     if (error != tinyxml2::XML_SUCCESS) {
-        printError(std::string("Cppcheck GUI project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
+        errors.emplace_back(std::string("Cppcheck GUI project file is not a valid XML - ") + tinyxml2::XMLDocument::ErrorIDToName(error));
         return false;
     }
     const tinyxml2::XMLElement * const rootnode = doc.FirstChildElement();
     if (rootnode == nullptr || strcmp(rootnode->Name(), CppcheckXml::ProjectElementName) != 0) {
-        printError("Cppcheck GUI project file has no XML root node");
+        errors.emplace_back("Cppcheck GUI project file has no XML root node");
         return false;
     }
 
@@ -1371,7 +1382,7 @@ bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings &setti
         else if (strcmp(name, CppcheckXml::AddonsElementName) == 0) {
             const auto& addons = readXmlStringList(node, "", CppcheckXml::AddonElementName, nullptr);
             temp.addons.insert(addons.cbegin(), addons.cend());
-            if (premium) {
+            if (settings.premium) {
                 auto it = temp.addons.find("misra");
                 if (it != temp.addons.end()) {
                     temp.addons.erase(it);
@@ -1417,7 +1428,7 @@ bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings &setti
                 else if (strcmp(childname, Settings::SafeChecks::XmlExternalVariables) == 0)
                     temp.safeChecks.externalVariables = true;
                 else {
-                    printError("Unknown '" + std::string(Settings::SafeChecks::XmlRootName) + "' element '" + childname + "' in Cppcheck project file");
+                    errors.emplace_back("Unknown '" + std::string(Settings::SafeChecks::XmlRootName) + "' element '" + childname + "' in Cppcheck project file");
                     return false;
                 }
             }
@@ -1440,7 +1451,7 @@ bool ImportProject::importCppcheckGuiProject(std::istream &istr, Settings &setti
         else if (strcmp(name, CppcheckXml::ProjectNameElementName) == 0)
             ; // no-op
         else {
-            printError("Unknown element '" + std::string(name) + "' in Cppcheck project file");
+            errors.emplace_back("Unknown element '" + std::string(name) + "' in Cppcheck project file");
             return false;
         }
     }
@@ -1502,7 +1513,6 @@ void ImportProject::selectOneVsConfig(Platform::Type platform)
     }
 }
 
-// cppcheck-suppress unusedFunction - used by GUI only
 void ImportProject::selectVsConfigurations(Platform::Type platform, const std::vector<std::string> &configurations)
 {
     for (auto it = fileSettings.cbegin(); it != fileSettings.cend();) {
@@ -1527,7 +1537,6 @@ void ImportProject::selectVsConfigurations(Platform::Type platform, const std::v
     }
 }
 
-// cppcheck-suppress unusedFunction - used by GUI only
 std::list<std::string> ImportProject::getVSConfigs()
 {
     return std::list<std::string>(mAllVSConfigs.cbegin(), mAllVSConfigs.cend());
@@ -1545,7 +1554,3 @@ void ImportProject::setRelativePaths(const std::string &filename)
     }
 }
 
-void ImportProject::printError(const std::string &message)
-{
-    std::cout << "cppcheck: error: " << message << std::endl;
-}
