@@ -25,6 +25,8 @@
 #include "vfvalue.h"
 
 #include <cctype>
+#include <cstdlib>
+#include <cstring>
 #include <fstream>
 #include <iostream>
 #include <map>
@@ -41,6 +43,9 @@
 
 std::atomic<bool> Settings::mTerminated;
 
+const int Settings::maxConfigsNotAssigned = 0;
+const int Settings::maxConfigsDefault = 12;
+
 const char Settings::SafeChecks::XmlRootName[] = "safe-checks";
 const char Settings::SafeChecks::XmlClasses[] = "class-public";
 const char Settings::SafeChecks::XmlExternalFunctions[] = "external-functions";
@@ -67,7 +72,6 @@ Settings::Settings()
 
 std::string Settings::loadCppcheckCfg(Settings& settings, Suppressions& suppressions, bool debug)
 {
-    // TODO: this always needs to be run *after* the Settings has been filled
     static const std::string cfgFilename = "cppcheck.cfg";
     std::string fileName;
 #ifdef FILESDIR
@@ -82,7 +86,7 @@ std::string Settings::loadCppcheckCfg(Settings& settings, Suppressions& suppress
     // cppcheck-suppress knownConditionTrueFalse
     if (fileName.empty()) {
         // TODO: make sure that exename is set
-        fileName = Path::getPathFromFilename(settings.exename) + cfgFilename;
+        fileName = Path::join(Path::getPathFromFilename(settings.exename), cfgFilename);
         if (debug)
             std::cout << "looking for '" << fileName << "'" << std::endl;
         if (!Path::isFile(fileName))
@@ -163,10 +167,12 @@ std::string Settings::loadCppcheckCfg(Settings& settings, Suppressions& suppress
             const auto& v = it->second;
             if (!v.is<bool>())
                 return "'safety' is not a bool";
-            settings.safety = settings.safety || v.get<bool>();
+            settings.safety = v.get<bool>();
         }
     }
 
+    settings.settingsFiles.emplace_back(std::move(fileName));
+
     return "";
 }
 
@@ -714,3 +720,9 @@ Settings::ExecutorType Settings::defaultExecutor()
 #endif
     return defaultExecutor;
 }
+
+bool Settings::unusedFunctionOnly()
+{
+    const char* unusedFunctionOnly = std::getenv("UNUSEDFUNCTION_ONLY");
+    return unusedFunctionOnly && (std::strcmp(unusedFunctionOnly, "1") == 0);
+}
