@@ -30,7 +30,6 @@
 #include <iostream>
 #include <fstream>
 #include <list>
-#include <map>
 #include <stdexcept>
 #include <utility>
 #include <vector>
@@ -46,8 +45,6 @@
 
 #include "xml.h"
 
-class SuppressionList;
-
 const Settings SimpleTokenizer::s_settings;
 
 // TODO: better path-only usage
@@ -114,67 +111,20 @@ ScopedFile::~ScopedFile() {
     }
 }
 
-// TODO: we should be using the actual Preprocessor implementation
-std::string PreprocessorHelper::getcode(const Settings& settings, ErrorLogger& errorlogger, const std::string &filedata, const std::string &cfg, const std::string &filename, SuppressionList *inlineSuppression)
-{
-    std::map<std::string, std::string> cfgcode = getcode(settings, errorlogger, filedata.c_str(), std::set<std::string>{cfg}, filename, inlineSuppression);
-    const auto it = cfgcode.find(cfg);
-    if (it == cfgcode.end())
-        return "";
-    return it->second;
-}
-
-std::map<std::string, std::string> PreprocessorHelper::getcode(const Settings& settings, ErrorLogger& errorlogger, const char code[], const std::string &filename, SuppressionList *inlineSuppression)
-{
-    return getcode(settings, errorlogger, code, {}, filename, inlineSuppression);
-}
-
-std::map<std::string, std::string> PreprocessorHelper::getcode(const Settings& settings, ErrorLogger& errorlogger, const char code[], std::set<std::string> cfgs, const std::string &filename, SuppressionList *inlineSuppression)
+void SimpleTokenizer2::preprocess(const char* code, std::size_t size, std::vector<std::string> &files, const std::string& file0, Tokenizer& tokenizer, ErrorLogger& errorlogger)
 {
     simplecpp::OutputList outputList;
-    std::vector<std::string> files;
+    simplecpp::TokenList tokens1(code, size, files, file0, &outputList);
 
-    std::istringstream istr(code);
-    simplecpp::TokenList tokens(istr, files, Path::simplifyPath(filename), &outputList);
-    Preprocessor preprocessor(settings, errorlogger, Path::identify(tokens.getFiles()[0], false));
-    if (inlineSuppression)
-        preprocessor.inlineSuppressions(tokens, *inlineSuppression);
-    preprocessor.removeComments(tokens);
-    preprocessor.simplifyPragmaAsm(tokens);
-
-    preprocessor.reportOutput(outputList, true);
-
-    if (Preprocessor::hasErrors(outputList))
-        return {};
-
-    std::map<std::string, std::string> cfgcode;
-    if (cfgs.empty())
-        cfgs = preprocessor.getConfigs(tokens);
-    for (const std::string & config : cfgs) {
-        try {
-            // TODO: also preserve location information when #include exists - enabling that will fail since #line is treated like a regular token
-            cfgcode[config] = preprocessor.getcode(tokens, config, files, std::string(code).find("#file") != std::string::npos);
-        } catch (const simplecpp::Output &) {
-            cfgcode[config] = "";
-        }
-    }
-
-    return cfgcode;
-}
-
-void SimpleTokenizer2::preprocess(const char code[], std::vector<std::string> &files, const std::string& file0, Tokenizer& tokenizer, ErrorLogger& errorlogger)
-{
-    // TODO: get rid of stream
-    std::istringstream istr(code);
-    const simplecpp::TokenList tokens1(istr, files, file0);
-
-    Preprocessor preprocessor(tokenizer.getSettings(), errorlogger, Path::identify(tokens1.getFiles()[0], false));
-    simplecpp::TokenList tokens2 = preprocessor.preprocess(tokens1, "", files, true);
+    Preprocessor preprocessor(tokens1, tokenizer.getSettings(), errorlogger, Path::identify(tokens1.getFiles()[0], false));
+    (void)preprocessor.loadFiles(files); // TODO: check result
+    simplecpp::TokenList tokens2 = preprocessor.preprocess("", files, outputList);
+    (void)preprocessor.reportOutput(outputList, true);
 
     // Tokenizer..
     tokenizer.list.createTokens(std::move(tokens2));
 
-    std::list<Directive> directives = preprocessor.createDirectives(tokens1);
+    std::list<Directive> directives = preprocessor.createDirectives();
     tokenizer.setDirectives(std::move(directives));
 }
 
