@@ -351,23 +351,29 @@ static void write_ossfuzz_makefile(std::vector<std::string> libfiles_prio, std::
 
     fout << "# This file is generated by dmake, do not edit.\n";
     fout << '\n';
-    fout << "# make CXX=clang++ MATCHCOMPILER=yes CXXFLAGS=\"-O1 -fno-omit-frame-pointer -gline-tables-only -DFUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION -fsanitize=address -fsanitize-address-use-after-scope -DHAVE_BOOST\" LIB_FUZZING_ENGINE=\"-fsanitize=fuzzer\" oss-fuzz-client\n";
+    fout << "# make CXX=clang++ MATCHCOMPILER=yes CXXOPTS=\"-O1 -fno-omit-frame-pointer -gline-tables-only -fsanitize=address -fsanitize-address-use-after-scope\" CPPOPTS=\"-DFUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION -DHAVE_BOOST\" LIB_FUZZING_ENGINE=\"-fsanitize=fuzzer\" oss-fuzz-client\n";
     fout << '\n';
     fout << "MATCHCOMPILER=yes\n"; // always need to enable the matchcompiler so the library files are being copied
     makeMatchcompiler(fout, "../", "--read-dir ../lib");
 
     fout << "INCS=-I../lib -isystem../externals/simplecpp -isystem../externals/tinyxml2 -isystem../externals/picojson\n";
-    fout << "CPPFLAGS=-std=c++11 -g -w $(INCS)\n";
+    fout << '\n';
+    fout << "override CXXFLAGS+=-std=c++11 -g -w\n";
+    fout << "override CPPFLAGS+=$(INCS)\n";
+    fout << '\n';
+    fout << "override CXXFLAGS += $(CXXOPTS)\n";
+    fout << "override CPPFLAGS += $(CPPOPTS)\n";
+    fout << "override LDFLAGS += $(LDOPTS)\n";
     fout << '\n';
     fout << "LIBOBJ =      " << objfiles(libfiles_prio) << "\n";
     fout << '\n';
     fout << "EXTOBJ =      " << objfiles(extfiles) << "\n";
     fout << '\n';
     fout << "oss-fuzz-client: $(EXTOBJ) $(LIBOBJ) main.o type2.o\n";
-    fout << "\t${CXX} $(CPPFLAGS) ${CXXFLAGS} -o $@ $^ ${LIB_FUZZING_ENGINE}\n";
+    fout << "\t${CXX} ${CXXFLAGS} -o $@ $^ ${LIB_FUZZING_ENGINE}\n";
     fout << '\n';
     fout << "no-fuzz: $(EXTOBJ) $(LIBOBJ) main_nofuzz.o type2.o\n";
-    fout << "\t${CXX} $(CPPFLAGS) ${CXXFLAGS} -o $@ $^\n";
+    fout << "\t${CXX} ${CXXFLAGS} -o $@ $^\n";
     fout << '\n';
     fout << "translate: translate.o type2.o\n";
     fout << "\t${CXX} -std=c++11 -g ${CXXFLAGS} -o $@ type2.cpp translate.cpp\n";
@@ -615,7 +621,7 @@ int main(int argc, char **argv)
          << "endif\n\n";
 
     // enable backtrac
-    fout << "RDYNAMIC=-rdynamic\n";
+    fout << "RDYNAMIC?=-rdynamic\n";
 
     // The _GLIBCXX_DEBUG doesn't work in cygwin or other Win32 systems.
     fout << "# Set the CPPCHK_GLIBCXX_DEBUG flag. This flag is not used in release Makefiles.\n"
@@ -708,7 +714,8 @@ int main(int argc, char **argv)
 
     // Makefile settings..
     if (release) {
-        makeConditionalVariable(fout, "CXXFLAGS", "-O2 -DNDEBUG -Wall -Wno-sign-compare -Wno-multichar");
+        makeConditionalVariable(fout, "CXXFLAGS", "-O2 -Wall -Wno-sign-compare -Wno-multichar");
+        fout << "override CPPFLAGS += -DNDEBUG\n\n";
     } else {
         makeConditionalVariable(fout, "CXXFLAGS",
                                 "-pedantic "
@@ -725,8 +732,8 @@ int main(int argc, char **argv)
                                 "-Wno-sign-compare "
                                 "-Wno-multichar "
                                 "-Woverloaded-virtual "
-                                "$(CPPCHK_GLIBCXX_DEBUG) "
                                 "-g");
+        //fout << "override CPPFLAGS += $(CPPCHK_GLIBCXX_DEBUG)\n\n"; // TODO: when using CXXOPTS this would always be set - need to handle this differently
     }
 
     fout << "ifeq (g++, $(findstring g++,$(CXX)))\n"
@@ -740,7 +747,8 @@ int main(int argc, char **argv)
          << "    ifeq ($(PCRE_CONFIG),)\n"
          << "        $(error Did not find pcre-config)\n"
          << "    endif\n"
-         << "    override CXXFLAGS += -DHAVE_RULES $(shell $(PCRE_CONFIG) --cflags)\n"
+         << "    override CXXFLAGS += $(shell $(PCRE_CONFIG) --cflags)\n"
+         << "    override CPPFLAGS += -DHAVE_RULES\n"
          << "    ifdef LIBS\n"
          << "        LIBS += $(shell $(PCRE_CONFIG) --libs)\n"
          << "    else\n"
@@ -750,11 +758,17 @@ int main(int argc, char **argv)
          << "    $(error invalid HAVE_RULES value '$(HAVE_RULES)')\n"
          << "endif\n\n";
 
+    fout << "override CXXFLAGS += $(CXXOPTS)\n";
+    fout << "override CPPFLAGS += $(CPPOPTS)\n";
+    fout << "override LDFLAGS += $(LDOPTS)\n\n";
+
     makeConditionalVariable(fout, "PREFIX", "/usr");
     makeConditionalVariable(fout, "INCLUDE_FOR_LIB", "-Ilib -isystem externals -isystem externals/picojson -isystem externals/simplecpp -isystem externals/tinyxml2");
     makeConditionalVariable(fout, "INCLUDE_FOR_FE", "-Ilib");
     makeConditionalVariable(fout, "INCLUDE_FOR_CLI", "-Ilib -Ifrontend -isystem externals/picojson -isystem externals/simplecpp -isystem externals/tinyxml2");
-    makeConditionalVariable(fout, "INCLUDE_FOR_TEST", "-Ilib -Ifrontend -Icli -isystem externals/simplecpp -isystem externals/tinyxml2");
+    makeConditionalVariable(fout, "INCLUDE_FOR_TEST", "-Ilib -Ifrontend -Icli -isystem externals/picojson -isystem externals/simplecpp -isystem externals/tinyxml2");
+
+    makeConditionalVariable(fout, "CFLAGS_FOR_TEST", "-Wno-dollar-in-identifier-extension");
 
     fout << "BIN=$(DESTDIR)$(PREFIX)/bin\n\n";
     fout << "# For 'make man': sudo apt-get install xsltproc docbook-xsl docbook-xml on Linux\n";
@@ -772,7 +786,7 @@ int main(int argc, char **argv)
     fout << ".PHONY: run-dmake tags\n\n";
     fout << "\n###### Targets\n\n";
     fout << "cppcheck: $(EXTOBJ) $(LIBOBJ) $(FEOBJ) $(CLIOBJ)\n";
-    fout << "\t$(CXX) $(CPPFLAGS) $(CXXFLAGS) -o $@ $^ $(LIBS) $(LDFLAGS) $(RDYNAMIC)\n\n";
+    fout << "\t$(CXX) $(CXXFLAGS) -o $@ $^ $(LIBS) $(LDFLAGS) $(RDYNAMIC)\n\n";
     fout << "all:\tcppcheck testrunner\n\n";
     std::string testrunner_clifiles_o;
     for (const std::string &clifile: clifiles) {
@@ -783,7 +797,7 @@ int main(int argc, char **argv)
         testrunner_clifiles_o += o;
     }
     fout << "testrunner: $(EXTOBJ) $(TESTOBJ) $(LIBOBJ) $(FEOBJ)" << testrunner_clifiles_o << "\n";
-    fout << "\t$(CXX) $(CPPFLAGS) $(CXXFLAGS) -o $@ $^ $(LIBS) $(LDFLAGS) $(RDYNAMIC)\n\n";
+    fout << "\t$(CXX) $(CXXFLAGS) -o $@ $^ $(LIBS) $(LDFLAGS) $(RDYNAMIC)\n\n";
     fout << "test:\tall\n";
     fout << "\t./testrunner\n\n";
     fout << "check:\tall\n";
@@ -867,13 +881,17 @@ int main(int argc, char **argv)
     fout << ".PHONY: validateRules\n";
     fout << "validateRules:\n";
     fout << "\txmllint --noout rules/*.xml\n";
+    fout << ".PHONY: check-nonneg\n";
+    fout << "check-nonneg:\n";
+    // TODO: how to use provided number of jobs?
+    fout << "\tls lib/*.cpp | xargs -n 1 -P $$(nproc) g++ -fsyntax-only -DNONNEG $(CXXFLAGS) $(INCLUDE_FOR_LIB)\n";
 
     fout << "\n###### Build\n\n";
 
     compilefiles(fout, libfiles_prio, "${INCLUDE_FOR_LIB}");
     compilefiles(fout, frontendfiles, "${INCLUDE_FOR_FE}");
     compilefiles(fout, clifiles, "${INCLUDE_FOR_CLI}");
-    compilefiles(fout, testfiles, "${INCLUDE_FOR_TEST}");
+    compilefiles(fout, testfiles, "${INCLUDE_FOR_TEST} ${CFLAGS_FOR_TEST}");
     compilefiles(fout, extfiles, "");
     compilefiles(fout, toolsfiles, "${INCLUDE_FOR_LIB}");
 
